@@ -14,10 +14,7 @@ class AirLoopHvac(DataObject):
 
     """Corresponds to IDD object `AirLoopHVAC` Defines a central forced air
     system."""
-    schema = {'min-fields': 10,
-              'name': u'AirLoopHVAC',
-              'pyname': u'AirLoopHvac',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -90,10 +87,13 @@ class AirLoopHvac(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 10,
+              'name': u'AirLoopHVAC',
+              'pyname': u'AirLoopHvac',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -364,10 +364,7 @@ class AirLoopHvacOutdoorAirSystemEquipmentList(DataObject):
     """ Corresponds to IDD object `AirLoopHVAC:OutdoorAirSystem:EquipmentList`
         List equipment in simulation order
     """
-    schema = {'min-fields': 0,
-              'name': u'AirLoopHVAC:OutdoorAirSystem:EquipmentList',
-              'pyname': u'AirLoopHvacOutdoorAirSystemEquipmentList',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -501,10 +498,13 @@ class AirLoopHvacOutdoorAirSystemEquipmentList(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 0,
+              'name': u'AirLoopHVAC:OutdoorAirSystem:EquipmentList',
+              'pyname': u'AirLoopHvacOutdoorAirSystemEquipmentList',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -992,10 +992,7 @@ class AirLoopHvacOutdoorAirSystem(DataObject):
         coils. From the perspective of the primary air loop the outdoor air system is treated
         as a single component.
     """
-    schema = {'min-fields': 3,
-              'name': u'AirLoopHVAC:OutdoorAirSystem',
-              'pyname': u'AirLoopHvacOutdoorAirSystem',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1024,10 +1021,13 @@ class AirLoopHvacOutdoorAirSystem(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 3,
+              'name': u'AirLoopHVAC:OutdoorAirSystem',
+              'pyname': u'AirLoopHvacOutdoorAirSystem',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1139,10 +1139,7 @@ class OutdoorAirMixer(DataObject):
         Outdoor air mixer. Node names cannot be duplicated within a single OutdoorAir:Mixer
         object or across all outdoor air mixers.
     """
-    schema = {'min-fields': 0,
-              'name': u'OutdoorAir:Mixer',
-              'pyname': u'OutdoorAirMixer',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1178,10 +1175,13 @@ class OutdoorAirMixer(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 0,
+              'name': u'OutdoorAir:Mixer',
+              'pyname': u'OutdoorAirMixer',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1321,10 +1321,13 @@ class AirLoopHvacZoneSplitter(DataObject):
         Split one air stream into N outlet streams (currently 500 per air loop, but extensible).  Node names
         cannot be duplicated within a single zone splitter (AirLoopHVAC:ZoneSplitter) list.
     """
-    schema = {'min-fields': 0,
-              'name': u'AirLoopHVAC:ZoneSplitter',
-              'pyname': u'AirLoopHvacZoneSplitter',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'outlet  node name',
+                                                 {'name': u'Outlet  Node Name',
+                                                  'pyname': u'outlet_node_name',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'node'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1339,16 +1342,13 @@ class AirLoopHvacZoneSplitter(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'outlet  node name',
-                                                 {'name': u'Outlet  Node Name',
-                                                  'pyname': u'outlet_node_name',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'node'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 0,
+              'name': u'AirLoopHVAC:ZoneSplitter',
+              'pyname': u'AirLoopHvacZoneSplitter',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1445,10 +1445,13 @@ class AirLoopHvacSupplyPlenum(DataObject):
         Connects 1 zone inlet air stream, through zone supply plenum, to one or more outlets.
         Node names cannot be duplicated within a single supply plenum list.
     """
-    schema = {'min-fields': 5,
-              'name': u'AirLoopHVAC:SupplyPlenum',
-              'pyname': u'AirLoopHvacSupplyPlenum',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'outlet node name',
+                                                 {'name': u'Outlet Node Name',
+                                                  'pyname': u'outlet_node_name',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'node'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1477,16 +1480,13 @@ class AirLoopHvacSupplyPlenum(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'outlet node name',
-                                                 {'name': u'Outlet Node Name',
-                                                  'pyname': u'outlet_node_name',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'node'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 5,
+              'name': u'AirLoopHVAC:SupplyPlenum',
+              'pyname': u'AirLoopHvacSupplyPlenum',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1633,10 +1633,22 @@ class AirLoopHvacSupplyPath(DataObject):
         A supply path can only contain AirLoopHVAC:ZoneSplitter and AirLoopHVAC:SupplyPlenum objects
         which may be in series or parallel.
     """
-    schema = {'min-fields': 0,
-              'name': u'AirLoopHVAC:SupplyPath',
-              'pyname': u'AirLoopHvacSupplyPath',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'component 1 object type',
+                                                 {'name': u'Component 1 Object Type',
+                                                  'pyname': u'component_1_object_type',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'accepted-values': [u'AirLoopHVAC:ZoneSplitter',
+                                                                      u'AirLoopHVAC:SupplyPlenum'],
+                                                     'autocalculatable': False,
+                                                     'type': 'alpha'}),
+                                                (u'component 1 name',
+                                                 {'name': u'Component 1 Name',
+                                                  'pyname': u'component_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1651,25 +1663,13 @@ class AirLoopHvacSupplyPath(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'component 1 object type',
-                                                 {'name': u'Component 1 Object Type',
-                                                  'pyname': u'component_1_object_type',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'accepted-values': [u'AirLoopHVAC:ZoneSplitter',
-                                                                      u'AirLoopHVAC:SupplyPlenum'],
-                                                  'autocalculatable': False,
-                                                  'type': 'alpha'}),
-                                                (u'component 1 name',
-                                                 {'name': u'Component 1 Name',
-                                                  'pyname': u'component_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 0,
+              'name': u'AirLoopHVAC:SupplyPath',
+              'pyname': u'AirLoopHvacSupplyPath',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1775,10 +1775,13 @@ class AirLoopHvacZoneMixer(DataObject):
         Mix N inlet air streams into one (currently 500 per air loop, but extensible).  Node names cannot
         be duplicated within a single zone mixer (AirLoopHVAC:ZoneMixer) list.
     """
-    schema = {'min-fields': 3,
-              'name': u'AirLoopHVAC:ZoneMixer',
-              'pyname': u'AirLoopHvacZoneMixer',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'inlet 1 node name',
+                                                 {'name': u'Inlet 1 Node Name',
+                                                  'pyname': u'inlet_1_node_name',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'node'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1793,16 +1796,13 @@ class AirLoopHvacZoneMixer(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'inlet 1 node name',
-                                                 {'name': u'Inlet 1 Node Name',
-                                                  'pyname': u'inlet_1_node_name',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'node'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 3,
+              'name': u'AirLoopHVAC:ZoneMixer',
+              'pyname': u'AirLoopHvacZoneMixer',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1900,10 +1900,13 @@ class AirLoopHvacReturnPlenum(DataObject):
         (currently 500 per air loop)
         Node names cannot be duplicated within a single plenum list.
     """
-    schema = {'min-fields': 6,
-              'name': u'AirLoopHVAC:ReturnPlenum',
-              'pyname': u'AirLoopHvacReturnPlenum',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'inlet node name',
+                                                 {'name': u'Inlet Node Name',
+                                                  'pyname': u'inlet_node_name',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'node'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1939,16 +1942,13 @@ class AirLoopHvacReturnPlenum(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'inlet node name',
-                                                 {'name': u'Inlet Node Name',
-                                                  'pyname': u'inlet_node_name',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'node'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 6,
+              'name': u'AirLoopHVAC:ReturnPlenum',
+              'pyname': u'AirLoopHvacReturnPlenum',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -2118,10 +2118,22 @@ class AirLoopHvacReturnPath(DataObject):
         A return air path can only contain one AirLoopHVAC:ZoneMixer
         and one or more AirLoopHVAC:ReturnPlenum objects.
     """
-    schema = {'min-fields': 0,
-              'name': u'AirLoopHVAC:ReturnPath',
-              'pyname': u'AirLoopHvacReturnPath',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'component 1 object type',
+                                                 {'name': u'Component 1 Object Type',
+                                                  'pyname': u'component_1_object_type',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'accepted-values': [u'AirLoopHVAC:ZoneMixer',
+                                                                      u'AirLoopHVAC:ReturnPlenum'],
+                                                     'autocalculatable': False,
+                                                     'type': 'alpha'}),
+                                                (u'component 1 name',
+                                                 {'name': u'Component 1 Name',
+                                                  'pyname': u'component_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -2136,25 +2148,13 @@ class AirLoopHvacReturnPath(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'node'})]),
-              'extensible-fields': OrderedDict([(u'component 1 object type',
-                                                 {'name': u'Component 1 Object Type',
-                                                  'pyname': u'component_1_object_type',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'accepted-values': [u'AirLoopHVAC:ZoneMixer',
-                                                                      u'AirLoopHVAC:ReturnPlenum'],
-                                                  'autocalculatable': False,
-                                                  'type': 'alpha'}),
-                                                (u'component 1 name',
-                                                 {'name': u'Component 1 Name',
-                                                  'pyname': u'component_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Air Distribution',
+              'min-fields': 0,
+              'name': u'AirLoopHVAC:ReturnPath',
+              'pyname': u'AirLoopHvacReturnPath',
               'required-object': False,
-              'group': u'Air Distribution'}
+              'unique-object': False}
 
     @property
     def name(self):
