@@ -19,10 +19,7 @@ class ControllerWaterCoil(DataObject):
         Coil:Cooling:Water:DetailedGeometry, and
         CoilSystem:Cooling:Water:HeatexchangerAssisted.
     """
-    schema = {'min-fields': 9,
-              'name': u'Controller:WaterCoil',
-              'pyname': u'ControllerWaterCoil',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -97,10 +94,13 @@ class ControllerWaterCoil(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'm3/s'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Controllers',
+              'min-fields': 9,
+              'name': u'Controller:WaterCoil',
+              'pyname': u'ControllerWaterCoil',
               'required-object': False,
-              'group': u'Controllers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -347,10 +347,7 @@ class ControllerOutdoorAir(DataObject):
         Controller to set the outdoor air flow rate for an air loop. Control options include
         fixed, proportional, scheduled, economizer, and demand-controlled ventilation.
     """
-    schema = {'min-fields': 16,
-              'name': u'Controller:OutdoorAir',
-              'pyname': u'ControllerOutdoorAir',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -569,10 +566,13 @@ class ControllerOutdoorAir(DataObject):
                                                            u'BypassWhenOAFlowGreaterThanMinimum'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Controllers',
+              'min-fields': 16,
+              'name': u'Controller:OutdoorAir',
+              'pyname': u'ControllerOutdoorAir',
               'required-object': False,
-              'group': u'Controllers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1298,10 +1298,27 @@ class ControllerMechanicalVentilation(DataObject):
         Duplicate groups of Zone name, Design Specification Outdoor Air Object Name,
         and Design Specification Zone Air Distribution Object Name to increase allowable number of entries
     """
-    schema = {'min-fields': 8,
-              'name': u'Controller:MechanicalVentilation',
-              'pyname': u'ControllerMechanicalVentilation',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'zone 1 name',
+                                                 {'name': u'Zone 1 Name',
+                                                  'pyname': u'zone_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'}),
+                                                (u'design specification outdoor air object name 1',
+                                                 {'name': u'Design Specification Outdoor Air Object Name 1',
+                                                  'pyname': u'design_specification_outdoor_air_object_name_1',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'}),
+                                                (u'design specification zone air distribution object name 1',
+                                                 {'name': u'Design Specification Zone Air Distribution Object Name 1',
+                                                  'pyname': u'design_specification_zone_air_distribution_object_name_1',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1349,30 +1366,13 @@ class ControllerMechanicalVentilation(DataObject):
                                        'autocalculatable': False,
                                        'type': u'real',
                                        'unit': u'dimensionless'})]),
-              'extensible-fields': OrderedDict([(u'zone 1 name',
-                                                 {'name': u'Zone 1 Name',
-                                                  'pyname': u'zone_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'}),
-                                                (u'design specification outdoor air object name 1',
-                                                 {'name': u'Design Specification Outdoor Air Object Name 1',
-                                                  'pyname': u'design_specification_outdoor_air_object_name_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'}),
-                                                (u'design specification zone air distribution object name 1',
-                                                 {'name': u'Design Specification Zone Air Distribution Object Name 1',
-                                                  'pyname': u'design_specification_zone_air_distribution_object_name_1',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Controllers',
+              'min-fields': 8,
+              'name': u'Controller:MechanicalVentilation',
+              'pyname': u'ControllerMechanicalVentilation',
               'required-object': False,
-              'group': u'Controllers'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1565,10 +1565,7 @@ class AirLoopHvacControllerList(DataObject):
     """ Corresponds to IDD object `AirLoopHVAC:ControllerList`
         List controllers in order of control sequence
     """
-    schema = {'min-fields': 0,
-              'name': u'AirLoopHVAC:ControllerList',
-              'pyname': u'AirLoopHvacControllerList',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1704,10 +1701,13 @@ class AirLoopHvacControllerList(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'object-list'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'Controllers',
+              'min-fields': 0,
+              'name': u'AirLoopHVAC:ControllerList',
+              'pyname': u'AirLoopHvacControllerList',
               'required-object': False,
-              'group': u'Controllers'}
+              'unique-object': False}
 
     @property
     def name(self):
