@@ -16,10 +16,24 @@ class DemandManagerAssignmentList(DataObject):
         a list of meters that can be reported are available after a run on
         the meter dictionary file (.mdd) if the Output:VariableDictionary has been requested.
     """
-    schema = {'min-fields': 0,
-              'name': u'DemandManagerAssignmentList',
-              'pyname': u'DemandManagerAssignmentList',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'demandmanager 1 object type',
+                                                 {'name': u'DemandManager 1 Object Type',
+                                                  'pyname': u'demandmanager_1_object_type',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'accepted-values': [u'DemandManager:ExteriorLights',
+                                                                      u'DemandManager:Lights',
+                                                                      u'DemandManager:ElectricEquipment',
+                                                                      u'DemandManager:Thermostats'],
+                                                     'autocalculatable': False,
+                                                     'type': 'alpha'}),
+                                                (u'demandmanager 1 name',
+                                                 {'name': u'DemandManager 1 Name',
+                                                  'pyname': u'demandmanager_1_name',
+                                                  'required-field': False,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -81,27 +95,13 @@ class DemandManagerAssignmentList(DataObject):
                                                            u'All'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict([(u'demandmanager 1 object type',
-                                                 {'name': u'DemandManager 1 Object Type',
-                                                  'pyname': u'demandmanager_1_object_type',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'accepted-values': [u'DemandManager:ExteriorLights',
-                                                                      u'DemandManager:Lights',
-                                                                      u'DemandManager:ElectricEquipment',
-                                                                      u'DemandManager:Thermostats'],
-                                                  'autocalculatable': False,
-                                                  'type': 'alpha'}),
-                                                (u'demandmanager 1 name',
-                                                 {'name': u'DemandManager 1 Name',
-                                                  'pyname': u'demandmanager_1_name',
-                                                  'required-field': False,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Demand Limiting Controls',
+              'min-fields': 0,
+              'name': u'DemandManagerAssignmentList',
+              'pyname': u'DemandManagerAssignmentList',
               'required-object': False,
-              'group': u'Demand Limiting Controls'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -361,10 +361,13 @@ class DemandManagerExteriorLights(DataObject):
     """ Corresponds to IDD object `DemandManager:ExteriorLights`
         used for demand limiting Exterior:Lights objects.
     """
-    schema = {'min-fields': 0,
-              'name': u'DemandManager:ExteriorLights',
-              'pyname': u'DemandManagerExteriorLights',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'exterior lights 1 name',
+                                                 {'name': u'Exterior Lights 1 Name',
+                                                  'pyname': u'exterior_lights_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -432,16 +435,13 @@ class DemandManagerExteriorLights(DataObject):
                                        'autocalculatable': False,
                                        'type': u'integer',
                                        'unit': u'minutes'})]),
-              'extensible-fields': OrderedDict([(u'exterior lights 1 name',
-                                                 {'name': u'Exterior Lights 1 Name',
-                                                  'pyname': u'exterior_lights_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Demand Limiting Controls',
+              'min-fields': 0,
+              'name': u'DemandManager:ExteriorLights',
+              'pyname': u'DemandManagerExteriorLights',
               'required-object': False,
-              'group': u'Demand Limiting Controls'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -694,10 +694,13 @@ class DemandManagerLights(DataObject):
     """ Corresponds to IDD object `DemandManager:Lights`
         used for demand limiting Lights objects.
     """
-    schema = {'min-fields': 0,
-              'name': u'DemandManager:Lights',
-              'pyname': u'DemandManagerLights',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'lights 1 name',
+                                                 {'name': u'Lights 1 Name',
+                                                  'pyname': u'lights_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -765,16 +768,13 @@ class DemandManagerLights(DataObject):
                                        'autocalculatable': False,
                                        'type': u'integer',
                                        'unit': u'minutes'})]),
-              'extensible-fields': OrderedDict([(u'lights 1 name',
-                                                 {'name': u'Lights 1 Name',
-                                                  'pyname': u'lights_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Demand Limiting Controls',
+              'min-fields': 0,
+              'name': u'DemandManager:Lights',
+              'pyname': u'DemandManagerLights',
               'required-object': False,
-              'group': u'Demand Limiting Controls'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1025,10 +1025,13 @@ class DemandManagerElectricEquipment(DataObject):
     """ Corresponds to IDD object `DemandManager:ElectricEquipment`
         used for demand limiting ElectricEquipment objects.
     """
-    schema = {'min-fields': 0,
-              'name': u'DemandManager:ElectricEquipment',
-              'pyname': u'DemandManagerElectricEquipment',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'electric equipment 1 name',
+                                                 {'name': u'Electric Equipment 1 Name',
+                                                  'pyname': u'electric_equipment_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1096,16 +1099,13 @@ class DemandManagerElectricEquipment(DataObject):
                                        'autocalculatable': False,
                                        'type': u'integer',
                                        'unit': u'minutes'})]),
-              'extensible-fields': OrderedDict([(u'electric equipment 1 name',
-                                                 {'name': u'Electric Equipment 1 Name',
-                                                  'pyname': u'electric_equipment_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Demand Limiting Controls',
+              'min-fields': 0,
+              'name': u'DemandManager:ElectricEquipment',
+              'pyname': u'DemandManagerElectricEquipment',
               'required-object': False,
-              'group': u'Demand Limiting Controls'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1358,10 +1358,13 @@ class DemandManagerThermostats(DataObject):
     """ Corresponds to IDD object `DemandManager:Thermostats`
         used for demand limiting ZoneControl:Thermostat objects.
     """
-    schema = {'min-fields': 0,
-              'name': u'DemandManager:Thermostats',
-              'pyname': u'DemandManagerThermostats',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict([(u'thermostat 1 name',
+                                                 {'name': u'Thermostat 1 Name',
+                                                  'pyname': u'thermostat_1_name',
+                                                  'required-field': True,
+                                                  'autosizable': False,
+                                                  'autocalculatable': False,
+                                                  'type': u'object-list'})]),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1436,16 +1439,13 @@ class DemandManagerThermostats(DataObject):
                                        'autocalculatable': False,
                                        'type': u'integer',
                                        'unit': u'minutes'})]),
-              'extensible-fields': OrderedDict([(u'thermostat 1 name',
-                                                 {'name': u'Thermostat 1 Name',
-                                                  'pyname': u'thermostat_1_name',
-                                                  'required-field': True,
-                                                  'autosizable': False,
-                                                  'autocalculatable': False,
-                                                  'type': u'object-list'})]),
-              'unique-object': False,
+              'format': None,
+              'group': u'Demand Limiting Controls',
+              'min-fields': 0,
+              'name': u'DemandManager:Thermostats',
+              'pyname': u'DemandManagerThermostats',
               'required-object': False,
-              'group': u'Demand Limiting Controls'}
+              'unique-object': False}
 
     @property
     def name(self):
