@@ -23,10 +23,7 @@ class ExternalInterface(DataObject):
     warning will be written to the EnergyPlus error file.
 
     """
-    schema = {'min-fields': 0,
-              'name': u'ExternalInterface',
-              'pyname': u'ExternalInterface',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name of external interface',
                                       {'name': u'Name of External Interface',
                                        'pyname': u'name_of_external_interface',
@@ -37,10 +34,13 @@ class ExternalInterface(DataObject):
                                                            u'FunctionalMockupUnitExport'],
                                        'autocalculatable': False,
                                        'type': 'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 0,
+              'name': u'ExternalInterface',
+              'pyname': u'ExternalInterface',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name_of_external_interface(self):
@@ -78,10 +78,7 @@ class ExternalInterfaceSchedule(DataObject):
         A ExternalInterface:Schedule contains only one value,
         which is used during the warm-up period and the system sizing.
     """
-    schema = {'min-fields': 3,
-              'name': u'ExternalInterface:Schedule',
-              'pyname': u'ExternalInterfaceSchedule',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -103,10 +100,13 @@ class ExternalInterfaceSchedule(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 3,
+              'name': u'ExternalInterface:Schedule',
+              'pyname': u'ExternalInterfaceSchedule',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -195,10 +195,7 @@ class ExternalInterfaceVariable(DataObject):
         is set to the value specified by the field "initial value." This object can be used
         to move data into Erl subroutines.
     """
-    schema = {'min-fields': 0,
-              'name': u'ExternalInterface:Variable',
-              'pyname': u'ExternalInterfaceVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -213,10 +210,13 @@ class ExternalInterfaceVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 0,
+              'name': u'ExternalInterface:Variable',
+              'pyname': u'ExternalInterfaceVariable',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -277,10 +277,7 @@ class ExternalInterfaceActuator(DataObject):
     """ Corresponds to IDD object `ExternalInterface:Actuator`
         Hardware portion of EMS used to set up actuators in the model
     """
-    schema = {'min-fields': 4,
-              'name': u'ExternalInterface:Actuator',
-              'pyname': u'ExternalInterfaceActuator',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -316,10 +313,13 @@ class ExternalInterfaceActuator(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 4,
+              'name': u'ExternalInterface:Actuator',
+              'pyname': u'ExternalInterfaceActuator',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -457,10 +457,7 @@ class ExternalInterfaceFunctionalMockupUnitImport(DataObject):
     """ Corresponds to IDD object `ExternalInterface:FunctionalMockupUnitImport`
         This object declares an FMU
     """
-    schema = {'min-fields': 0,
-              'name': u'ExternalInterface:FunctionalMockupUnitImport',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitImport',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'fmu file name',
                                       {'name': u'FMU File Name',
                                        'pyname': u'fmu_file_name',
@@ -485,10 +482,13 @@ class ExternalInterfaceFunctionalMockupUnitImport(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'integer'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 0,
+              'name': u'ExternalInterface:FunctionalMockupUnitImport',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitImport',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def fmu_file_name(self):
@@ -574,10 +574,7 @@ class ExternalInterfaceFunctionalMockupUnitImportFromVariable(DataObject):
     """ Corresponds to IDD object `ExternalInterface:FunctionalMockupUnitImport:From:Variable`
         This object declares an FMU input variable
     """
-    schema = {'min-fields': 5,
-              'name': u'ExternalInterface:FunctionalMockupUnitImport:From:Variable',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportFromVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'output:variable index key name',
                                       {'name': u'Output:Variable Index Key Name',
                                        'pyname': u'outputvariable_index_key_name',
@@ -613,10 +610,13 @@ class ExternalInterfaceFunctionalMockupUnitImportFromVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 5,
+              'name': u'ExternalInterface:FunctionalMockupUnitImport:From:Variable',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportFromVariable',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def outputvariable_index_key_name(self):
@@ -750,10 +750,7 @@ class ExternalInterfaceFunctionalMockupUnitImportToSchedule(DataObject):
         This objects contains only one value, which is used during the first
         call of EnergyPlus
     """
-    schema = {'min-fields': 6,
-              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Schedule',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToSchedule',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -796,10 +793,13 @@ class ExternalInterfaceFunctionalMockupUnitImportToSchedule(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 6,
+              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Schedule',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToSchedule',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -961,10 +961,7 @@ class ExternalInterfaceFunctionalMockupUnitImportToActuator(DataObject):
         Hardware portion of EMS used to set up actuators in the model
         that are dynamically updated from the FMU.
     """
-    schema = {'min-fields': 8,
-              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Actuator',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToActuator',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1021,10 +1018,13 @@ class ExternalInterfaceFunctionalMockupUnitImportToActuator(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 8,
+              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Actuator',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToActuator',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1237,10 +1237,7 @@ class ExternalInterfaceFunctionalMockupUnitImportToVariable(DataObject):
         Declares Erl variable as having global scope
         No spaces allowed in names used for Erl variables
     """
-    schema = {'min-fields': 5,
-              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Variable',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1276,10 +1273,13 @@ class ExternalInterfaceFunctionalMockupUnitImportToVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 5,
+              'name': u'ExternalInterface:FunctionalMockupUnitImport:To:Variable',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitImportToVariable',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1416,10 +1416,7 @@ class ExternalInterfaceFunctionalMockupUnitExportFromVariable(DataObject):
     """ Corresponds to IDD object `ExternalInterface:FunctionalMockupUnitExport:From:Variable`
         This object declares an FMU input variable
     """
-    schema = {'min-fields': 3,
-              'name': u'ExternalInterface:FunctionalMockupUnitExport:From:Variable',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportFromVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'output:variable index key name',
                                       {'name': u'Output:Variable Index Key Name',
                                        'pyname': u'outputvariable_index_key_name',
@@ -1441,10 +1438,13 @@ class ExternalInterfaceFunctionalMockupUnitExportFromVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'alpha'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 3,
+              'name': u'ExternalInterface:FunctionalMockupUnitExport:From:Variable',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportFromVariable',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def outputvariable_index_key_name(self):
@@ -1528,10 +1528,7 @@ class ExternalInterfaceFunctionalMockupUnitExportToSchedule(DataObject):
         This objects contains only one value, which is used during the first
         call of EnergyPlus
     """
-    schema = {'min-fields': 4,
-              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Schedule',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToSchedule',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'schedule name',
                                       {'name': u'Schedule Name',
                                        'pyname': u'schedule_name',
@@ -1560,10 +1557,13 @@ class ExternalInterfaceFunctionalMockupUnitExportToSchedule(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 4,
+              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Schedule',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToSchedule',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def schedule_name(self):
@@ -1675,10 +1675,7 @@ class ExternalInterfaceFunctionalMockupUnitExportToActuator(DataObject):
         Hardware portion of EMS used to set up actuators in the model
         that are dynamically updated from the FMU.
     """
-    schema = {'min-fields': 6,
-              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Actuator',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToActuator',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1721,10 +1718,13 @@ class ExternalInterfaceFunctionalMockupUnitExportToActuator(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 6,
+              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Actuator',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToActuator',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
@@ -1887,10 +1887,7 @@ class ExternalInterfaceFunctionalMockupUnitExportToVariable(DataObject):
         Declares Erl variable as having global scope
         No spaces allowed in names used for Erl variables
     """
-    schema = {'min-fields': 3,
-              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Variable',
-              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToVariable',
-              'format': None,
+    schema = {'extensible-fields': OrderedDict(),
               'fields': OrderedDict([(u'name',
                                       {'name': u'Name',
                                        'pyname': u'name',
@@ -1912,10 +1909,13 @@ class ExternalInterfaceFunctionalMockupUnitExportToVariable(DataObject):
                                        'autosizable': False,
                                        'autocalculatable': False,
                                        'type': u'real'})]),
-              'extensible-fields': OrderedDict(),
-              'unique-object': False,
+              'format': None,
+              'group': u'External Interface',
+              'min-fields': 3,
+              'name': u'ExternalInterface:FunctionalMockupUnitExport:To:Variable',
+              'pyname': u'ExternalInterfaceFunctionalMockupUnitExportToVariable',
               'required-object': False,
-              'group': u'External Interface'}
+              'unique-object': False}
 
     @property
     def name(self):
