@@ -28,6 +28,15 @@ class DataObject(object):
         raise NotImplementedError(
             "add_extensible is not implemented for class DataObject")
 
+    def keys(self):
+        keys = []
+        for field in self.schema['fields'].values():
+            keys.append(field['name'])
+        for i in range(len(self._extdata)):
+            for field in self.schema['extensible-fields'].values():
+                keys.append((field['name'], i))
+        return keys
+
     def __setitem__(self, key, value):
         if isinstance(key, six.string_types):
             key_lower = key.lower()
@@ -194,7 +203,7 @@ class DataObject(object):
                     'No field exists with name in data object`{}`'.format(
                         schema['name']))
             else:
-                raise logger.warn(
+                logger.warn(
                     'No field exists with name in data object`{}`'.format(
                         schema['name']))
                 return value
@@ -212,7 +221,7 @@ class DataObject(object):
                     value = float(value)
                 else:
                     value = str(value)
-            except TypeError:
+            except (TypeError, ValueError):
                 return value
             return value
 
@@ -270,7 +279,7 @@ class DataObject(object):
                     value = float(value)
                 else:
                     value = str(value)
-            except TypeError:
+            except (TypeError, ValueError):
                 if pyidf.validation_level == ValidationLevel.no:
                     return value
 
